=============================
django-hstore (schemaless DB)
=============================

.. image:: https://travis-ci.org/djangonauts/django-hstore.png
   :target: https://travis-ci.org/djangonauts/django-hstore

.. image:: https://coveralls.io/repos/djangonauts/django-hstore/badge.png
  :target: https://coveralls.io/r/djangonauts/django-hstore

.. image:: https://landscape.io/github/djangonauts/django-hstore/master/landscape.png
   :target: https://landscape.io/github/djangonauts/django-hstore/master
   :alt: Code Health

.. image:: https://requires.io/github/djangonauts/django-hstore/requirements.png?branch=master
   :target: https://requires.io/github/djangonauts/django-hstore/requirements/?branch=master
   :alt: Requirements Status

.. image:: https://badge.fury.io/py/django-hstore.png
    :target: http://badge.fury.io/py/django-hstore

.. image:: https://pypip.in/d/django-hstore/badge.png
    :target: http://badge.fury.io/py/django-hstore


Documentation: http://djangonauts.github.io/django-hstore/

Mailing List: https://groups.google.com/forum/#!forum/django-hstore
